<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>MediaPlayer</source>
        <translation>MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>MPRIS Player</source>
        <translation>MPRIS Player</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerConfigurationUiHandler</name>
    <message>
        <source>Select Player:</source>
        <translation>Selecione o player:</translation>
    </message>
    <message>
        <source>Add Player</source>
        <translation>Adicionar player</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar player</translation>
    </message>
    <message>
        <source>Delete Player</source>
        <translation>Apagar player</translation>
    </message>
</context>
<context>
    <name>MPRISPlayerDialog</name>
    <message>
        <source>Add Player</source>
        <translation>Adicionar player</translation>
    </message>
    <message>
        <source>Edit Player</source>
        <translation>Editar player</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Player: </translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Serviço:</translation>
    </message>
</context>
</TS>